@@ -19,6 +19,7 @@ import Prelude hiding (tail, init, last, minimum, maximum, foldr1, foldl1, (!!),
 import Control.Arrow
 import Data.List (isPrefixOf)
 import Data.Char
+import Data.Maybe
 import Data.Time
 import Safe
 import qualified Data.Time.Locale.Compat as LC
@@ -29,7 +30,22 @@ type Header = (String, String)
 
 -- | Reads a date header as a UTCTime
 parseDateHeader :: String -> Maybe UTCTime
-parseDateHeader = parseTime LC.defaultTimeLocale  "%A, %B %e, %Y %l:%M %p"
+parseDateHeader header = listToMaybe . catMaybes $ map tryParse formats where
+  tryParse f = parseTime LC.defaultTimeLocale f header
+  formats =
+    [ "%a, %_d %b %Y %T %z"
+    , "%a, %_d %b %Y %T %Z"
+    , "%a, %d %b %Y %T %z"
+    , "%a, %d %b %Y %T %Z"
+    , "%a, %_d %b %Y %T %z (%Z)"
+    , "%a, %_d %b %Y %T %z (GMT%:-z)"
+    , "%a, %_d %b %Y %T %z (UTC%:-z)"
+    , "%a, %_d %b %Y %T %z (GMT%:z)"
+    , "%a, %_d %b %Y %T %z (UTC%:z)"
+    , "%A, %B %e, %Y %l:%M %p"
+    , "%e %b %Y %T %z"
+    ]
+
 
 -- | Attempts to retrieve the contents of a forwarded message from an enclosing message.
 parseForward :: Message -> Message
@@ -90,5 +106,5 @@ isID (x, _y) = x == "Message-ID"
 isDate :: Header -> Bool
 isDate (x, _y) = x == "Date"
 
-getHeader :: (Header -> Bool) -> Message -> String
-getHeader p = snd . head . filter p . headers
+getHeader :: (Header -> Bool) -> Message -> [String]
+getHeader p = map snd . filter p . headers
